==> qtarmsim-0.2.6.tar.gz: qtarmsim-0.2.6/qtarmsim/comm/responses.py <==
# -*- coding: utf-8 -*-

###########################################################################
#                                                                         #
#  This file is part of Qt ARMSim.                                        #
#                                                                         #
#  Qt ARMSim is free software: you can redistribute it and/or modify      #
#  it under the terms of the GNU General Public License as published by   #
#  the Free Software Foundation; either version 3 of the License, or      #
#  (at your option) any later version.                                    #
#                                                                         #
#  This program is distributed in the hope that it will be useful, but    #
#  WITHOUT ANY WARRANTY; without even the implied warranty of             #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      #
#  General Public License for more details.                               #
#                                                                         #
###########################################################################

## Execute response container
class ExecuteResponse():
    
    def __init__(self):
        self.result = ""
        self.assembly_line = ""
        self.registers = []
        self.memory = []
        self.errmsg = ""

## Assemble response container
class AssembleResponse():
    
    def __init__(self):
        self.result = ""
        self.errmsg = ""

==> qtarmsim-0.5.1.tar.gz: qtarmsim-0.5.1/qtarmsim/comm/responses.py <==
# -*- coding: utf-8 -*-

###########################################################################
#                                                                         #
#  This file is part of QtARMSim.                                         #
#                                                                         #
#  QtARMSim is free software: you can redistribute it and/or modify       #
#  it under the terms of the GNU General Public License as published by   #
#  the Free Software Foundation; either version 3 of the License, or      #
#  (at your option) any later version.                                    #
#                                                                         #
#  This program is distributed in the hope that it will be useful, but    #
#  WITHOUT ANY WARRANTY; without even the implied warranty of             #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      #
#  General Public License for more details.                               #
#                                                                         #
###########################################################################

## Execute response container
class ExecuteResponse:

    def __init__(self):
        self.result = ""
        self.assembly_line = ""
        self.registers = []
        self.memory = []
        self.errmsg = ""


## Assemble response container
class AssembleResponse:

    def __init__(self):
        self.result = ""
        self.errmsg = ""
